function [vIMT, vPoE,sLoc] = GetEfehrHazCurve(fLon,fLat,sIMT,sSoilType,sAggregationType,fAggLevel)
% [vIMT, vPoE,sLoc] = GetEfehrHazCurve(fLon,fLat,sIMT,sSoilType,sAggregationType,fAggLevel)
% -------------------------------------------------------------------------
% Function to extract Hazard Curve data from EFEHR-portal for one location
% Location is changed to the closest computed point by the webservice 
%
% Input parameters:
% fLon: geogr. Longitude
% fLat: geogr. Latitude
% sIMT: Intensity measure type, e.g. PGA, SA[0.10s]
% sSoilType: Soil class, default 'rock'
% sAggregationType: ordinal, arithmetic (for the mean)
% fAggLevel: Fractile of the hazard curve (0.05, 0.15, 0.5 0.85 0.95)
%
% Output data:
% vIMT: Vector of the IMT-values
% vPoE: Matrix of the Probability of Exceedance values of the hazard curve
%       with [5% 15% Mean Median 85% 95%]
% sLoc: Location of the exact point (Lon Lat)
%
% Example:
% Get mean hazard curve for PGA
% [vIMT, mPoE] = GetEfehrHazCurve(7.,47.5,'PGA','rock','arithmetic',0.5)
% Get mean hazard curve for 4s
% [vIMT, mPoE] = GetEfehrHazCurve(7.,47.5,'SA[4.00s]','rock','arithmetic',0.5)
% Get 15% fractile for PGA
% [vIMT, mPoE] = GetEfehrHazCurve(7.,47.5,'PGA','rock','ordinal',0.15)
% 
% Copyright (C) 2010 by J. Woessner
% 12.08.2013
% j.woessner@sed.ethz.ch
%
%% Licence
% SHARE data and products are released under the Creative Commons 
% Attribution-ShareAlike 3.0 Unported (CC BY-SA 3.0) licence.
%  
% For all SHARE datasets the following notice applies and/or is included within the files:
%  
% Copyright ? 2013, ETH Zurich on behalf of the EU-FP7 Consortium of SHARE
% 
% You may use this work under the terms of the CC BY-SA 3.0 (unported) 
% [http://creativecommons.org/licenses/by-sa/3.0/]
% 
% THE WORK IS PROTECTED BY COPYRIGHT AND/OR OTHER APPLICABLE LAW. INSOFAR 
% AS THIS WORK IS PROTECTED BY LAWS THAT NEIGHBOUR OR ARE SIMILARLY RELATED
% TO COPYRIGHT, SUCH AS DATABASE RIGHTS AS INTRODUCED IN EUROPE BY THE  
% DIRECTIVE 96/9/EC, YOU ALSO MAY USE THIS WORK UNDER THE TERMS OF 
% CC-BY-SA 3.0 (unported).
% 
% ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR 
% DIRECTLY ALLOWED BY THE APPLICABLE LAW IS PROHIBITED.
% 
% If you alter, transform, or build upon this work, you may distribute the 
% resulting work only under the same or similar license to this one. 
% 
% If you have any questions, or if you wish to seek permission to use this 
% data beyond what is offered by CC BY-SA 3.0 (unported), please contact 
% representatives of the EU-FP7 SHARE consortium at: 
% 
%  
% ETH Zurich / Swiss Seismological Service
% Sonneggstrasse 5
% CH-8092 Zurich, Switzerland
% email: share@sed.ethz.ch
% Tel.: +41-44-633-2179


%% Download data using webservice of EFEHR
sUrl = ['http://appsrvr.share-eu.org:8080/share/'];
% 1. Get available model ID(s) for the location
sUrlModel = [sUrl 'curve?lat=' num2str(fLat) '&lon=' num2str(fLon)];

% Write to xml-file
urlwrite(sUrlModel,'TMPmodel.xml');
m=xmlread('TMPmodel.xml');
fModel=m.getElementsByTagName('id').item(0).getTextContent;

% Define dowload string
sCurve = ['http://appsrvr.share-eu.org:8080/share/curve?id=' char(fModel) '&lon=' num2str(fLon) '&lat=' num2str(fLat) '&imt=' sIMT '&soiltype=' sSoilType '&aggregationtype=' sAggregationType '&aggregationlevel=' num2str(fAggLevel)];
%urlwrite(' http://appsrvr.share-eu.org:8080/share/curve?id=71&lon=7.&lat=47.5&imt=PGA&soiltype=rock&aggregationtype=arithmetic&aggregationlevel=0.5','curve.xml')

% Get data via webservice and write to XML-file
urlwrite(sCurve,'TMPcurve.xml');
% Read back XML-data
DOM = xmlread('TMPcurve.xml');
% Get data from the xml-data
vIMT=DOM.getElementsByTagName('ns2:IML').item(0).getTextContent;
vPoE = DOM.getElementsByTagName('ns2:poE').item(0).getTextContent;
sLoc = DOM.getElementsByTagName('ns1:pos').item(0).getTextContent;